@@ -1,23 +1,19 @@
 from __future__ import with_statement, unicode_literals
 import os
 import codecs
+from importlib import import_module
 
 from django.core.files.base import ContentFile
-from django.template import Context
-from django.template.loader import render_to_string
-from django.utils.importlib import import_module
 from django.utils.safestring import mark_safe
-
-try:
-    from urllib.request import url2pathname
-except ImportError:
-    from urllib import url2pathname
+from django.utils.six.moves.urllib.request import url2pathname
+from django.template.loader import render_to_string
 
 from compressor.cache import get_hexdigest, get_mtime
 from compressor.conf import settings
 from compressor.exceptions import (CompressorError, UncompressableFileError,
         FilterDoesNotExist)
-from compressor.filters import CompilerFilter
+from compressor.filters import CachedCompilerFilter
+from compressor.filters.css_default import CssAbsoluteFilter
 from compressor.storage import compressor_file_storage
 from compressor.signals import post_compress
 from compressor.utils import get_class, get_mod_func, staticfiles
@@ -33,17 +29,19 @@ class Compressor(object):
     Base compressor object to be subclassed for content type
     depending implementations details.
     """
-    type = None
 
-    def __init__(self, content=None, output_prefix=None, context=None, *args, **kwargs):
+    def __init__(self, content=None, output_prefix=None,
+                 context=None, filters=None, *args, **kwargs):
         self.content = content or ""  # rendered contents of {% compress %} tag
         self.output_prefix = output_prefix or "compressed"
         self.output_dir = settings.COMPRESS_OUTPUT_DIR.strip('/')
         self.charset = settings.DEFAULT_CHARSET
         self.split_content = []
         self.context = context or {}
+        self.type = output_prefix or ""
+        self.filters = filters or []
         self.extra_context = {}
-        self.all_mimetypes = dict(settings.COMPRESS_PRECOMPILERS)
+        self.precompiler_mimetypes = dict(settings.COMPRESS_PRECOMPILERS)
         self.finders = staticfiles.finders
         self._storage = None
 
@@ -114,18 +112,21 @@ class Compressor(object):
         get_filename('css/one.css') -> '/full/path/to/static/css/one.css'
         """
         filename = None
-        # first try finding the file in the root
-        try:
-            # call path first so remote storages don't make it to exists,
-            # which would cause network I/O
-            filename = self.storage.path(basename)
-            if not self.storage.exists(basename):
-                filename = None
-        except NotImplementedError:
-            # remote storages don't implement path, access the file locally
-            if compressor_file_storage.exists(basename):
-                filename = compressor_file_storage.path(basename)
-        # secondly try to find it with staticfiles (in debug mode)
+        # First try finding the file using the storage class.
+        # This is skipped in DEBUG mode as files might be outdated in
+        # compressor's final destination (COMPRESS_ROOT) during development
+        if not settings.DEBUG:
+            try:
+                # call path first so remote storages don't make it to exists,
+                # which would cause network I/O
+                filename = self.storage.path(basename)
+                if not self.storage.exists(basename):
+                    filename = None
+            except NotImplementedError:
+                # remote storages don't implement path, access the file locally
+                if compressor_file_storage.exists(basename):
+                    filename = compressor_file_storage.path(basename)
+        # secondly try to find it with staticfiles
         if not filename and self.finders:
             filename = self.finders.find(url2pathname(basename))
         if filename:
@@ -140,6 +141,9 @@ class Compressor(object):
         """
         Reads file contents using given `charset` and returns it as text.
         """
+        if charset == 'utf-8':
+            # Removes BOM
+            charset = 'utf-8-sig'
         with codecs.open(filename, 'r', charset) as fd:
             try:
                 return fd.read()
@@ -196,24 +200,28 @@ class Compressor(object):
                 options = dict(options, filename=value)
                 value = self.get_filecontent(value, charset)
 
-            if self.all_mimetypes:
+            if self.precompiler_mimetypes:
                 precompiled, value = self.precompile(value, **options)
 
             if enabled:
-                yield self.filter(value, **options)
+                yield self.filter(value, self.cached_filters, **options)
+            elif precompiled:
+                # since precompiling moves files around, it breaks url()
+                # statements in css files. therefore we run the absolute filter
+                # on precompiled css files even if compression is disabled.
+                if CssAbsoluteFilter in self.cached_filters:
+                    value = self.filter(value, [CssAbsoluteFilter], **options)
+                yield self.handle_output(kind, value, forced=True,
+                                         basename=basename)
             else:
-                if precompiled:
-                    yield self.handle_output(kind, value, forced=True,
-                                             basename=basename)
-                else:
-                    yield self.parser.elem_str(elem)
+                yield self.parser.elem_str(elem)
 
     def filter_output(self, content):
         """
         Passes the concatenated content to the 'output' methods
         of the compressor filters.
         """
-        return self.filter(content, method=METHOD_OUTPUT)
+        return self.filter(content, self.cached_filters, method=METHOD_OUTPUT)
 
     def filter_input(self, forced=False):
         """
@@ -236,37 +244,36 @@ class Compressor(object):
             return False, content
         attrs = self.parser.elem_attribs(elem)
         mimetype = attrs.get("type", None)
-        if mimetype:
-            filter_or_command = self.all_mimetypes.get(mimetype)
-            if filter_or_command is None:
-                if mimetype not in ("text/css", "text/javascript"):
-                    raise CompressorError("Couldn't find any precompiler in "
-                                          "COMPRESS_PRECOMPILERS setting for "
-                                          "mimetype '%s'." % mimetype)
-            else:
-                mod_name, cls_name = get_mod_func(filter_or_command)
-                try:
-                    mod = import_module(mod_name)
-                except ImportError:
-                    filter = CompilerFilter(
-                        content, filter_type=self.type, filename=filename,
-                        charset=charset, command=filter_or_command)
-                    return True, filter.input(**kwargs)
-                try:
-                    precompiler_class = getattr(mod, cls_name)
-                except AttributeError:
-                    raise FilterDoesNotExist('Could not find "%s".' %
-                            filter_or_command)
-                else:
-                    filter = precompiler_class(
-                        content, attrs, filter_type=self.type, charset=charset,
-                        filename=filename)
-                    return True, filter.input(**kwargs)
+        if mimetype is None:
+            return False, content
 
-        return False, content
+        filter_or_command = self.precompiler_mimetypes.get(mimetype)
+        if filter_or_command is None:
+            if mimetype in ("text/css", "text/javascript"):
+                return False, content
+            raise CompressorError("Couldn't find any precompiler in "
+                                  "COMPRESS_PRECOMPILERS setting for "
+                                  "mimetype '%s'." % mimetype)
 
-    def filter(self, content, method, **kwargs):
-        for filter_cls in self.cached_filters:
+        mod_name, cls_name = get_mod_func(filter_or_command)
+        try:
+            mod = import_module(mod_name)
+        except (ImportError, TypeError):
+            filter = CachedCompilerFilter(
+                content=content, filter_type=self.type, filename=filename,
+                charset=charset, command=filter_or_command, mimetype=mimetype)
+            return True, filter.input(**kwargs)
+        try:
+            precompiler_class = getattr(mod, cls_name)
+        except AttributeError:
+            raise FilterDoesNotExist('Could not find "%s".' % filter_or_command)
+        filter = precompiler_class(
+            content, attrs=attrs, filter_type=self.type, charset=charset,
+            filename=filename)
+        return True, filter.input(**kwargs)
+
+    def filter(self, content, filters, method, **kwargs):
+        for filter_cls in filters:
             filter_func = getattr(
                 filter_cls(content, filter_type=self.type), method)
             try:
@@ -332,8 +339,14 @@ class Compressor(object):
 
         self.context['compressed'].update(context or {})
         self.context['compressed'].update(self.extra_context)
-        final_context = Context(self.context)
+        if hasattr(self.context, 'flatten'):
+            # Django 1.8 complains about Context being passed to its
+            # Template.render function.
+            final_context = self.context.flatten()
+        else:
+            final_context = self.context
+
         post_compress.send(sender=self.__class__, type=self.type,
                            mode=mode, context=final_context)
         template_name = self.get_template_name(mode)
-        return render_to_string(template_name, context_instance=final_context)
+        return render_to_string(template_name, context=final_context)
