@@ -1,6 +1,7 @@
+from importlib import import_module
+
 from django.utils import six
 from django.utils.functional import LazyObject
-from django.utils.importlib import import_module
 
 # support legacy parser module usage
 from compressor.parser.base import ParserBase  # noqa
@@ -30,5 +31,5 @@ class AutoSelectParser(LazyObject):
                 import_module(dependency)
                 self._wrapped = parser(content)
                 break
-            except ImportError:
+            except (ImportError, TypeError):
                 continue
